@@ -13,20 +13,23 @@ from cms.models import (Page, Title, CMSPlugin, PagePermission,
 from cms.models.managers import PagePermissionsPermissionManager
 from cms.models.placeholdermodel import Placeholder
 from cms.plugin_pool import plugin_pool
+from cms.templatetags.cms_admin import admin_static_url
 from cms.utils import (copy_plugins, helpers, moderator, permissions, plugins, 
     get_template_from_request, get_language_from_request, 
     placeholder as placeholder_utils, admin as admin_utils, cms_static_url)
 from cms.utils.permissions import has_plugin_permission
 from copy import deepcopy
+from distutils.version import LooseVersion
 from django import template
 from django.conf import settings
 from django.contrib import admin
 from django.contrib.admin.options import IncorrectLookupParameters
-from django.contrib.admin.util import unquote, get_deleted_objects
+from django.contrib.admin.util import get_deleted_objects
+from urllib2 import unquote
 from django.contrib.sites.models import Site
 from django.core.exceptions import PermissionDenied, ObjectDoesNotExist
 from django.core.urlresolvers import reverse
-from django.db import transaction, models
+from django.db import router, transaction, models
 from django.forms import CharField
 from django.http import (HttpResponseRedirect, HttpResponse, Http404, 
     HttpResponseBadRequest, HttpResponseForbidden, HttpResponseNotAllowed)
@@ -38,15 +41,9 @@ from django.utils.encoding import force_unicode
 from django.utils.translation import ugettext, ugettext_lazy as _
 from menus.menu_pool import menu_pool
 import django
-import inspect
 
 
-
-# silly hack to test features/ fixme
-if inspect.getargspec(get_deleted_objects)[0][-1] == 'using':
-    from django.db import router
-else:
-    router = False
+DJANGO_1_3 = LooseVersion(django.get_version()) < LooseVersion('1.4')
 
 if 'reversion' in settings.INSTALLED_APPS:
     import reversion
@@ -56,6 +53,17 @@ else: # pragma: no cover
     from django.contrib.admin import ModelAdmin
     create_on_success = lambda x: x
 
+if DJANGO_1_3:
+    """
+    Backwards compatibility for Django < 1.4 and django-reversion 1.6
+    """
+    class ModelAdmin(ModelAdmin):
+        def get_inline_instances(self, request):
+            return self.inline_instances
+        
+        def get_prepopulated_fields(self, request):
+            return self.prepopulated_fields
+
 
 def contribute_fieldsets(cls):
     if settings.CMS_MENU_TITLE_OVERWRITE:
@@ -168,7 +176,7 @@ class PageAdmin(ModelAdmin):
                 'css/jquery.dialog.css',
             )]
         }
-        js = ['%sjs/jquery.min.js' % settings.ADMIN_MEDIA_PREFIX] + [cms_static_url(path) for path in [
+        js = ['%sjs/jquery.min.js' % admin_static_url()] + [cms_static_url(path) for path in [
                 'js/plugins/admincompat.js',
                 'js/libs/jquery.query.js',
                 'js/libs/jquery.ui.core.js',
@@ -204,6 +212,7 @@ class PageAdmin(ModelAdmin):
             pat(r'^([0-9]+)/remove-delete-state/$', self.remove_delete_state),
             pat(r'^([0-9]+)/dialog/copy/$', get_copy_dialog), # copy dialog
             pat(r'^([0-9]+)/preview/$', self.preview_page), # copy dialog
+            pat(r'^([0-9]+)/descendants/$', self.descendants), # menu html for page descendants
             pat(r'^(?P<object_id>\d+)/change_template/$', self.change_template), # copy dialog
         )
 
@@ -461,7 +470,9 @@ class PageAdmin(ModelAdmin):
     # remove permission inlines, if user isn't allowed to change them
     def get_formsets(self, request, obj=None):
         if obj:
-            for inline in self.inline_instances:
+            inlines = self.get_inline_instances(request) if hasattr(self, 'get_inline_instances') \
+                      else self.inline_instances
+            for inline in inlines:
                 if settings.CMS_PERMISSION and isinstance(inline, PagePermissionInlineAdmin) and not isinstance(inline, ViewRestrictionInlineAdmin):
                     if "recover" in request.path or "history" in request.path: #do not display permissions in recover mode
                         continue
@@ -489,7 +500,7 @@ class PageAdmin(ModelAdmin):
         extra_context.update({
             'language': language,
         })
-        return super(PageAdmin, self).add_view(request, form_url, extra_context)
+        return super(PageAdmin, self).add_view(request, form_url, extra_context=extra_context)
 
     def change_view(self, request, object_id, extra_context=None):
         """
@@ -518,7 +529,7 @@ class PageAdmin(ModelAdmin):
                 'page': obj,
                 'CMS_PERMISSION': settings.CMS_PERMISSION,
                 'CMS_MODERATOR': settings.CMS_MODERATOR,
-                'ADMIN_MEDIA_URL': settings.ADMIN_MEDIA_PREFIX,
+                'ADMIN_MEDIA_URL': settings.STATIC_URL,
                 'has_change_permissions_permission': obj.has_change_permissions_permission(request),
                 'has_moderate_permission': obj.has_moderate_permission(request),
                 'moderation_level': moderation_level,
@@ -530,7 +541,7 @@ class PageAdmin(ModelAdmin):
             }
             extra_context = self.update_language_tab_context(request, obj, extra_context)
         tab_language = request.GET.get("language", None)
-        response = super(PageAdmin, self).change_view(request, object_id, extra_context)
+        response = super(PageAdmin, self).change_view(request, object_id, extra_context=extra_context)
 
         if tab_language and response.status_code == 302 and response._headers['location'][1] == request.path :
             location = response._headers['location']
@@ -639,12 +650,12 @@ class PageAdmin(ModelAdmin):
         if not self.has_change_permission(request, None):
             raise PermissionDenied
         try:
-            if hasattr(self, 'list_editable'):# django 1.1
+            if DJANGO_1_3:
                 cl = CMSChangeList(request, self.model, self.list_display, self.list_display_links, self.list_filter,
                     self.date_hierarchy, self.search_fields, self.list_select_related, self.list_per_page, self.list_editable, self)
-            else:# django 1.0.2
+            else:
                 cl = CMSChangeList(request, self.model, self.list_display, self.list_display_links, self.list_filter,
-                    self.date_hierarchy, self.search_fields, self.list_select_related, self.list_per_page, self)
+                    self.date_hierarchy, self.search_fields, self.list_select_related, self.list_per_page, self.list_max_show_all, self.list_editable, self)
         except IncorrectLookupParameters:
             # Wacky lookup parameters were given, so redirect to the main
             # changelist page, without parameters, and pass an 'invalid=1'
@@ -667,14 +678,23 @@ class PageAdmin(ModelAdmin):
             languages = settings.CMS_SITE_LANGUAGES[site_id]
         else:
             languages = [x[0] for x in settings.CMS_LANGUAGES]
-        
+
+        # parse the cookie that saves which page trees have
+        # been opened already and extracts the page ID
+        djangocms_nodes_open = request.COOKIES.get('djangocms_nodes_open', '')
+        raw_nodes = unquote(djangocms_nodes_open).split(',')
+        try:
+            open_menu_trees = [int(c.split('page_', 1)[1]) for c in raw_nodes]
+        except IndexError:
+            open_menu_trees = []
+
         context = {
             'title': cl.title,
             'is_popup': cl.is_popup,
             'cl': cl,
             'opts':opts,
             'has_add_permission': self.has_add_permission(request),
-            'root_path': self.admin_site.root_path,
+            'root_path': reverse('admin:index'),
             'app_label': app_label,
             'CMS_MEDIA_URL': settings.CMS_MEDIA_URL,
             'softroot': settings.CMS_SOFTROOT,
@@ -683,6 +703,7 @@ class PageAdmin(ModelAdmin):
             'has_recover_permission': 'reversion' in settings.INSTALLED_APPS and self.has_recover_permission(request),
             'DEBUG': settings.DEBUG,
             'site_languages': languages,
+            'open_menu_trees': open_menu_trees,
         }
         if 'reversion' in settings.INSTALLED_APPS:
             context['has_change_permission'] = self.has_change_permission(request)
@@ -935,19 +956,12 @@ class PageAdmin(ModelAdmin):
         titleobj = get_object_or_404(Title, page__id=object_id, language=language)
         saved_plugins = CMSPlugin.objects.filter(placeholder__page__id=object_id, language=language)
         
-        if django.VERSION[1] > 2: # pragma: no cover
-            # WARNING: Django 1.3 is not officially supported yet!
-            using = router.db_for_read(self.model)
-            kwargs = {
-                'admin_site': self.admin_site,
-                'user': request.user,
-                'using': using
-            }
-        else:
-            kwargs = {
-                'admin_site': self.admin_site,
-                'user': request.user,
-            }
+        using = router.db_for_read(self.model)
+        kwargs = {
+            'admin_site': self.admin_site,
+            'user': request.user,
+            'using': using
+        }
         deleted_objects, perms_needed =  get_deleted_objects(
             [titleobj],
             titleopts,
@@ -993,8 +1007,8 @@ class PageAdmin(ModelAdmin):
             "object": titleobj,
             "deleted_objects": deleted_objects,
             "perms_lacking": perms_needed,
-            "opts": titleopts,
-            "root_path": self.admin_site.root_path,
+            "opts": opts,
+            "root_path": reverse('admin:index'),
             "app_label": app_label,
         }
         context.update(extra_context or {})
@@ -1042,7 +1056,7 @@ class PageAdmin(ModelAdmin):
         Switch the status of a page
         """
         if request.method != 'POST':
-            return HttpResponseNotAllowed
+            return HttpResponseNotAllowed(['POST'])
         page = get_object_or_404(Page, pk=page_id)
         if page.has_publish_permission(request):
             page.published = not page.published
@@ -1057,7 +1071,7 @@ class PageAdmin(ModelAdmin):
         """
         # why require post and still have page id in the URL???
         if request.method != 'POST':
-            return HttpResponseNotAllowed
+            return HttpResponseNotAllowed(['POST'])
         page = get_object_or_404(Page, pk=page_id)
         if page.has_change_permission(request):
             page.in_navigation = not page.in_navigation
@@ -1065,6 +1079,18 @@ class PageAdmin(ModelAdmin):
             return admin_utils.render_admin_menu_item(request, page)
         return HttpResponseForbidden(_("You do not have permission to change this page's in_navigation status"))
 
+    def descendants(self, request, page_id):
+        """
+        Get html for descendants of given page
+        Used for lazy loading pages in change_list.js
+        
+        Permission checks is done in admin_utils.get_admin_menu_item_context
+        which is called by admin_utils.render_admin_menu_item.
+        """
+        page = get_object_or_404(Page, pk=page_id)
+        return admin_utils.render_admin_menu_item(request, page,
+                template="admin/cms/page/lazy_menu.html")
+                
     @create_on_success
     def add_plugin(self, request):
         '''
@@ -1189,7 +1215,6 @@ class PageAdmin(ModelAdmin):
             from reversion.models import Version
             pre_edit = request.path.split("/edit-plugin/")[0]
             version_id = pre_edit.split("/")[-1]
-            Version.objects.get(pk=version_id)
             version = get_object_or_404(Version, pk=version_id)
             rev_objs = []
             for related_version in version.revision.version_set.all():
@@ -1227,7 +1252,7 @@ class PageAdmin(ModelAdmin):
             pass
         if request.method == "POST":
             # set the continue flag, otherwise will plugin_admin make redirect to list
-            # view, which actually does'nt exists
+            # view, which actually doesn't exists
             request.POST['_continue'] = True
 
         if 'reversion' in settings.INSTALLED_APPS and ('history' in request.path or 'recover' in request.path):
@@ -1235,6 +1260,27 @@ class PageAdmin(ModelAdmin):
             context = RequestContext(request)
             return render_to_response(plugin_admin.render_template, plugin_admin.render(context, instance, plugin_admin.placeholder))
 
+        if request.POST.get("_cancel", False):
+            # cancel button was clicked
+            context = {
+                'CMS_MEDIA_URL': settings.CMS_MEDIA_URL,
+                'plugin': cms_plugin,
+                'is_popup': True,
+                'name': unicode(cms_plugin),
+                "type": cms_plugin.get_plugin_name(),
+                'plugin_id': plugin_id,
+                'icon': force_escape(escapejs(cms_plugin.get_instance_icon_src())),
+                'alt': force_escape(escapejs(cms_plugin.get_instance_icon_alt())),
+                'cancel': True,
+            }
+            instance = cms_plugin.get_plugin_instance()[0]
+            if not instance:
+                # cancelled before any content was added to plugin
+                cms_plugin.delete()
+                context.update({
+                    "deleted":True,
+                })
+            return render_to_response('admin/cms/page/plugin_forms_ok.html', context, RequestContext(request))
 
         if not instance:
             # instance doesn't exist, call add view
@@ -1268,8 +1314,8 @@ class PageAdmin(ModelAdmin):
                 'name': unicode(saved_object),
                 "type": saved_object.get_plugin_name(),
                 'plugin_id': plugin_id,
-                'icon': force_escape(escapejs(saved_object.get_instance_icon_src())),
-                'alt': force_escape(escapejs(saved_object.get_instance_icon_alt())),
+                'icon': force_escape(saved_object.get_instance_icon_src()),
+                'alt': force_escape(saved_object.get_instance_icon_alt()),
             }
             return render_to_response('admin/cms/page/plugin_forms_ok.html', context, RequestContext(request))
 
@@ -1302,6 +1348,10 @@ class PageAdmin(ModelAdmin):
             # plugin positions are 0 based, so just using count here should give us 'last_position + 1'
             position = CMSPlugin.objects.filter(placeholder=placeholder).count()
             plugin.position = position
+            # update the placeholder on all descendant plugins as well
+            for child in plugin.get_descendants():
+                child.placeholder = placeholder
+                child.save()
             plugin.save()
             success = True
         if 'ids' in request.POST:
@@ -1377,7 +1427,7 @@ class PageAdmin(ModelAdmin):
         """
         from cms.models.moderatormodels import MASK_PAGE, MASK_CHILDREN, MASK_DESCENDANTS
         if request.method != 'POST':
-            return HttpResponseNotAllowed
+            return HttpResponseNotAllowed(['POST'])
         page = get_object_or_404(Page, id=page_id)
         moderate = request.POST.get('moderate', None)
         if moderate is not None and page.has_moderate_permission(request):
