@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from django.conf import settings
 from patch import pre_patch, post_patch, post_patch_check
+import warnings
 
 
 
@@ -14,6 +15,12 @@ def patch_settings():
         return
     patch_settings.ALREADY_PATCHED = True
     
+    if getattr(settings, 'CMS_FLAT_URLS', False):
+        warnings.warn("CMS_FLAT_URLS are deprecated and will be removed in django CMS 2.4!", DeprecationWarning)
+    
+    if getattr(settings, 'CMS_MODERATOR', False):
+        warnings.warn("CMS_MODERATOR will be removed and replaced in django CMS 2.4!", DeprecationWarning)
+    
     from cms.conf import global_settings
     # patch settings
     
@@ -30,4 +37,4 @@ def patch_settings():
     if settings.DEBUG:
         # check if settings are correct, call this only if debugging is enabled
         post_patch_check()
-patch_settings.ALREADY_PATCHED = False
\ No newline at end of file
+patch_settings.ALREADY_PATCHED = False
