@@ -2,51 +2,99 @@
 from collections import defaultdict
 from cms.apphook_pool import apphook_pool
 from cms.models.moderatormodels import (ACCESS_DESCENDANTS, 
-    ACCESS_PAGE_AND_DESCENDANTS, ACCESS_CHILDREN, ACCESS_PAGE_AND_CHILDREN)
+    ACCESS_PAGE_AND_DESCENDANTS, ACCESS_CHILDREN, ACCESS_PAGE_AND_CHILDREN, ACCESS_PAGE)
 from cms.models.permissionmodels import PagePermission, GlobalPagePermission
 from cms.models.titlemodels import Title
 from cms.utils import get_language_from_request
 from cms.utils.i18n import get_fallback_languages
 from cms.utils.moderator import get_page_queryset, get_title_queryset
 from cms.utils.plugins import current_site
-from django.conf import settings
-from django.contrib.sites.models import Site
-from django.db.models.query_utils import Q
 from menus.base import Menu, NavigationNode, Modifier
 from menus.menu_pool import menu_pool
 
+from django.conf import settings
+from django.contrib.sites.models import Site
+from django.db.models.query_utils import Q
+from django.contrib.auth.models import Permission
 
 def get_visible_pages(request, pages, site=None):
-    # This code is basically a many-pages-at-once version of
-    # Page.has_view_permission, check there to see wtf is going on here.
-    if request.user.is_staff and settings.CMS_PUBLIC_FOR in ('staff', 'all'):
-        return [page.pk for page in pages]
-    page_ids = []
+    """
+     This code is basically a many-pages-at-once version of
+     Page.has_view_permission.
+     pages contains all published pages
+     check if there is ANY restriction
+     that needs a permission page visibility calculation
+    """
+    is_setting_public_all = settings.CMS_PUBLIC_FOR == 'all'
+    is_setting_public_staff = settings.CMS_PUBLIC_FOR == 'staff'
+    is_auth_user = request.user.is_authenticated()
     
+    visible_page_ids = []
+    restricted_pages = defaultdict(list)
     pages_perms_q = Q()
+
     for page in pages:
+        # taken from for_page as multiple at once version
         page_q = Q(page__tree_id=page.tree_id) & (
             Q(page=page) 
             | (Q(page__level__lt=page.level)  & (Q(grant_on=ACCESS_DESCENDANTS) | Q(grant_on=ACCESS_PAGE_AND_DESCENDANTS)))
             | (Q(page__level=page.level - 1) & (Q(grant_on=ACCESS_CHILDREN) | Q(grant_on=ACCESS_PAGE_AND_CHILDREN)))  
         ) 
         pages_perms_q |= page_q
+        
+        
     pages_perms_q &= Q(can_view=True)
     page_permissions = PagePermission.objects.filter(pages_perms_q).select_related('page', 'group__users')
-    
-    restricted_pages = defaultdict(list)
+
     for perm in page_permissions:
-        restricted_pages[perm.page.pk].append(perm)
+        # collect the pages that are affected by permissions
+        if perm is not None and perm not in restricted_pages[perm.page.pk]:
+            # affective restricted pages gathering
+            # using mptt functions 
+            # add the page with the perm itself
+            if perm.grant_on in [ACCESS_PAGE, ACCESS_PAGE_AND_CHILDREN ,ACCESS_PAGE_AND_DESCENDANTS]:
+                restricted_pages[perm.page.pk].append(perm)
+            # add children    
+            if perm.grant_on in [ACCESS_CHILDREN, ACCESS_PAGE_AND_CHILDREN]: 
+                child_ids = perm.page.get_children().values_list('id', flat=True)
+                for id in child_ids:
+                    restricted_pages[id].append(perm)
+            # add descendants
+            elif perm.grant_on in [ACCESS_DESCENDANTS, ACCESS_PAGE_AND_DESCENDANTS]: 
+                child_ids = perm.page.get_descendants().values_list('id', flat=True)
+                for id in child_ids:
+                    restricted_pages[id].append(perm)
+    # anonymous 
+    # no restriction applied at all
+    if (not is_auth_user and 
+        is_setting_public_all and 
+        not restricted_pages):
+        return [page.pk for page in pages] 
     
+   
     if site is None:
         site = current_site(request)
     
-    if request.user.is_authenticated():
-        #return self.filter(Q(user=user) | Q(group__user=user))
+    # authenticated user and global permission
+    if is_auth_user:
         global_page_perm_q = Q(
             Q(user=request.user) | Q(group__user=request.user)
         ) & Q(can_view=True) & Q(Q(sites__in=[site.pk]) | Q(sites__isnull=True))
         global_view_perms = GlobalPagePermission.objects.filter(global_page_perm_q).exists()
+ 
+        #no page perms edgcase - all visible
+        if ((is_setting_public_all or (
+            is_setting_public_staff and request.user.is_staff))and 
+            not restricted_pages and
+            not global_view_perms):
+            return [page.pk for page in pages]
+        #no page perms edgcase - none visible
+        elif (is_setting_public_staff and 
+            not request.user.is_staff and 
+            not restricted_pages and
+            not global_view_perms):
+            return []
+           
         
     def has_global_perm():
         if has_global_perm.cache < 0:
@@ -54,38 +102,56 @@ def get_visible_pages(request, pages, site=None):
         return bool(has_global_perm.cache)
     has_global_perm.cache = -1
     
-    def has_permission(page):
+    def has_permission_membership(page):
         """
-        PagePermission tests
+        PagePermission user group membership tests
         """
-        for perm in restricted_pages[page.pk]:
-            if perm.user_id == request.user.pk:
-                return True
-        for perm in restricted_pages[page.pk]:
+        user_pk = request.user.pk
+        page_pk = page.pk
+        has_perm = False
+        for perm in restricted_pages[page_pk]:
+            if perm.user_id == user_pk:
+                has_perm = True
             if not perm.group_id:
                 continue
-            if request.user.pk in perm.group.user_set.values_list('id', flat=True):
-                return True
-        return False
+            group_user_ids = perm.group.user_set.values_list('pk', flat=True)
+            if user_pk in group_user_ids:
+                has_perm = True
+        return has_perm
     
     for page in pages:
+        to_add = False
+        # default to false, showing a restricted page is bad
+        # explicitly check all the conditions
+        # of settings and permissions
         is_restricted = page.pk in restricted_pages
-        
-        if request.user.is_authenticated():
+        # restricted_pages contains as key any page.pk that is 
+        # affected by a permission grant_on
+        if is_auth_user:
             # a global permission was given to the request's user
             if global_view_perms:
-                page_ids.append(page.pk)
-            # authenticated user, no restriction and public for all
-            elif settings.CMS_PUBLIC_FOR == 'all':
-                page_ids.append(page.pk)
-            elif has_permission(page):
-                page_ids.append(page.pk)
+                to_add = True
+            # setting based handling of unrestricted pages
+            elif not is_restricted and (
+                     is_setting_public_all or (
+                       is_setting_public_staff and request.user.is_staff)
+                     ): 
+                # authenticated user, no restriction and public for all
+                # or 
+                # authenticated staff user, no restriction and public for staff
+                to_add = True
+            # check group and user memberships to restricted pages
+            elif is_restricted and has_permission_membership(page):
+                to_add = True
             elif has_global_perm():
-                page_ids.append(page.pk)
-        elif not is_restricted and settings.CMS_PUBLIC_FOR == 'all':
-            # anonymous user, no restriction saved in database
-            page_ids.append(page.pk)
-    return page_ids
+                to_add = True
+        # anonymous user, no restriction  
+        elif not is_restricted and is_setting_public_all:
+            to_add = True
+        # store it
+        if to_add:
+            visible_page_ids.append(page.pk)
+    return visible_page_ids
 
 def page_to_node(page, home, cut):
     '''
@@ -178,7 +244,6 @@ class CMSMenu(Menu):
         
         # cache view perms
         visible_pages = get_visible_pages(request, pages, site)
-
         for page in pages:
             # Pages are ordered by tree_id, therefore the first page is the root
             # of the page tree (a.k.a "home")
@@ -190,8 +255,6 @@ class CMSMenu(Menu):
             page.home_pk_cache = home.pk
             if first and page.pk != home.pk:
                 home_cut = True
-            elif not settings.CMS_PUBLIC_FOR == 'all':
-                continue
             if (page.parent_id == home.pk or page.parent_id in home_children) and home_cut:
                 home_children.append(page.pk)
             if (page.pk == home.pk and home.in_navigation) or page.pk != home.pk:
@@ -277,7 +340,70 @@ menu_pool.register_modifier(NavExtender)
 
 class SoftRootCutter(Modifier):
     """
-    If anyone understands this, PLEASE write a meaningful description here!
+    Ask evildmp/superdmp if you don't understand softroots!
+    
+    Softroot description from the docs:
+    
+        A soft root is a page that acts as the root for a menu navigation tree.
+    
+        Typically, this will be a page that is the root of a significant new
+        section on your site.
+    
+        When the soft root feature is enabled, the navigation menu for any page
+        will start at the nearest soft root, rather than at the real root of
+        the site’s page hierarchy.
+    
+        This feature is useful when your site has deep page hierarchies (and
+        therefore multiple levels in its navigation trees). In such a case, you
+        usually don’t want to present site visitors with deep menus of nested
+        items.
+    
+        For example, you’re on the page -Introduction to Bleeding-?, so the menu
+        might look like this:
+    
+            School of Medicine
+                Medical Education
+                Departments
+                    Department of Lorem Ipsum
+                    Department of Donec Imperdiet
+                    Department of Cras Eros
+                    Department of Mediaeval Surgery
+                        Theory
+                        Cures
+                        Bleeding
+                            Introduction to Bleeding <this is the current page>
+                            Bleeding - the scientific evidence
+                            Cleaning up the mess
+                            Cupping
+                            Leaches
+                            Maggots
+                        Techniques
+                        Instruments
+                    Department of Curabitur a Purus
+                    Department of Sed Accumsan
+                    Department of Etiam
+                Research
+                Administration
+                Contact us
+                Impressum
+    
+        which is frankly overwhelming.
+    
+        By making -Department of Mediaeval Surgery-? a soft root, the menu
+        becomes much more manageable:
+    
+            Department of Mediaeval Surgery
+                Theory
+                Cures
+                    Bleeding
+                        Introduction to Bleeding <current page>
+                        Bleeding - the scientific evidence
+                        Cleaning up the mess
+                    Cupping
+                    Leaches
+                    Maggots
+                Techniques
+                Instruments
     """
     def modify(self, request, nodes, namespace, root_id, post_cut, breadcrumb):
         # only apply this modifier if we're pre-cut (since what we do is cut)
@@ -305,13 +431,7 @@ class SoftRootCutter(Modifier):
             else:
                 # if it's not a soft root, walk ancestors (upwards!)
                 nodes = self.find_ancestors_and_remove_children(selected, nodes)
-            # remove child-softroots from descendants (downwards!)
-            nodes = self.find_and_remove_children(selected, nodes)
-        else:
-            # for all nodes in root, remove child-sofroots (downwards!)
-            for node in root_nodes:
-                self.find_and_remove_children(node, nodes)
-        return nodes   
+        return nodes
     
     def find_and_remove_children(self, node, nodes):
         for n in node.children:
