@@ -1,19 +1,16 @@
 # -*- coding: utf-8 -*-
 from django.conf import settings
 from django.db.models.base import ModelBase
-from publisher.manager import PublisherManager
-from publisher.mptt_support import install_mptt, finish_mptt
-from publisher.options import PublisherOptions
+from cms.publisher.manager import PublisherManager
+from mptt.models import MPTTModelBase
+from cms.publisher.options import PublisherOptions
 
 
-class PageMetaClass(ModelBase):
+class PageMetaClass(MPTTModelBase):
     def __new__(cls, name, bases, attrs):
         super_new = super(PageMetaClass, cls).__new__
         if not settings.CMS_MODERATOR:
-            attrs = install_mptt(cls, name, bases, attrs)
-            new_class = super_new(cls, name, bases, attrs)
-            finish_mptt(new_class)
-            return new_class
+            return super_new(cls, name, bases, attrs)
         
         if 'objects' in attrs:
             if not isinstance(attrs['objects'], PublisherManager):
@@ -28,11 +25,5 @@ class PageMetaClass(ModelBase):
         # build meta object
         publisher_meta = attrs.pop('PublisherMeta', None)
         attrs['_publisher_meta'] = PublisherOptions(name, bases, publisher_meta)
-                    
         
-        # take care of mptt, if required
-        attrs = install_mptt(cls, name, bases, attrs)
-        
-        new_class = super_new(cls, name, bases, attrs)
-        finish_mptt(new_class)
-        return new_class
\ No newline at end of file
+        return super_new(cls, name, bases, attrs)
