@@ -1,15 +1,14 @@
 # -*- coding: utf-8 -*-
-from cms.models.managers import BasicPagePermissionManager, \
-    PagePermissionManager
-from cms.models.moderatormodels import ACCESS_CHOICES, \
-    ACCESS_PAGE_AND_DESCENDANTS
-from cms.models.pagemodel import Page
-from cms.utils.helpers import reversion_register
-from django.contrib.auth.models import User, Group
-from django.contrib.sites.models import Site
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
 
+from django.contrib.auth.models import User, Group
+from django.contrib.sites.models import Site
+
+from cms.models import Page, ACCESS_CHOICES, ACCESS_PAGE_AND_DESCENDANTS
+from cms.models.managers import BasicPagePermissionManager, PagePermissionManager
+from cms.utils.helpers import reversion_register
+
 class AbstractPagePermission(models.Model):
     """Abstract page permissions
     """
@@ -26,15 +25,15 @@ class AbstractPagePermission(models.Model):
     can_change_permissions = models.BooleanField(_("can change permissions"), default=False, help_text=_("on page level"))
     can_move_page = models.BooleanField(_("can move"), default=True)
     can_moderate = models.BooleanField(_("can moderate"), default=True)
+    can_view = models.BooleanField(_("view restricted"), default=False, help_text=_("frontend view restriction"))
     
     class Meta:
         abstract = True
         app_label = 'cms'
-
-        
+    
     @property
     def audience(self):
-        """Return audience by priority, so: All or User, Group                
+        """Return audience by priority, so: All or User, Group
         """
         targets = filter(lambda item: item, (self.user, self.group,))
         return ", ".join([unicode(t) for t in targets]) or 'No one'
@@ -43,9 +42,9 @@ class AbstractPagePermission(models.Model):
         if not self.user and not self.group:
             # don't allow `empty` objects
             return
-        return super(AbstractPagePermission, self).save(*args, **kwargs)    
+        return super(AbstractPagePermission, self).save(*args, **kwargs)
+
 
-    
 class GlobalPagePermission(AbstractPagePermission):
     """Permissions for all pages (global).
     """
@@ -59,7 +58,8 @@ class GlobalPagePermission(AbstractPagePermission):
         verbose_name_plural = _('Pages global permissions')
         app_label = 'cms'
     
-    __unicode__ = lambda self: "%s :: GLOBAL" % self.audience
+    def __unicode__(self):
+        return "%s :: GLOBAL" % self.audience
 
 
 class PagePermission(AbstractPagePermission):
@@ -74,10 +74,11 @@ class PagePermission(AbstractPagePermission):
         verbose_name = _('Page permission')
         verbose_name_plural = _('Page permissions')
         app_label = 'cms'
-        
+    
     def __unicode__(self):
         page = self.page_id and unicode(self.page) or "None"
-        return "%s :: %s has: %s" % (page, self.audience, unicode(dict(ACCESS_CHOICES)[self.grant_on][1]))
+        return "%s :: %s has: %s" % (page, self.audience, unicode(dict(ACCESS_CHOICES)[self.grant_on]))
+
 
 class PageUser(User):
     """Cms specific user data, required for permission system
@@ -88,21 +89,17 @@ class PageUser(User):
         verbose_name = _('User (page)')
         verbose_name_plural = _('Users (page)')
         app_label = 'cms'
-    
-    #__unicode__ = lambda self: unicode(self.user)
-        
+
+
 class PageUserGroup(Group):
     """Cms specific group data, required for permission system 
     """
-    #group = models.OneToOneField(Group)
     created_by = models.ForeignKey(User, related_name="created_usergroups")
     
     class Meta:
         verbose_name = _('User group (page)')
         verbose_name_plural = _('User groups (page)')
         app_label = 'cms'
-        
-    #__unicode__ = lambda self: unicode(self.group)
 
 
 reversion_register(PagePermission)
\ No newline at end of file
