@@ -16,8 +16,5 @@ class GoogleMapPlugin(CMSPluginBase):
             'placeholder':placeholder, 
         })
         return context
-    
-    def get_plugin_media(self, request, context, plugin):
-        return Media(js = ('http://maps.google.com/maps/api/js?sensor=true',))
 
 plugin_pool.register_plugin(GoogleMapPlugin)
\ No newline at end of file
