@@ -27,4 +27,7 @@ from cms.tests.templatetags import *
 from cms.tests.toolbar import *
 from cms.tests.urlutils import *
 from cms.tests.views import *
-from cms.tests.management import *
\ No newline at end of file
+from cms.tests.management import *
+from cms.tests.menu_page_viewperm import *
+from cms.tests.menu_page_viewperm_staff import *
+from cms.tests.nested_plugins import *
\ No newline at end of file
