@@ -12,14 +12,15 @@ from cms.test_utils.util.context_managers import (SettingsOverride,
 from cms.test_utils.util.mock import AttributeObject
 from django.conf import settings
 from django.contrib.auth.models import AnonymousUser, User, Permission, Group
-from django.contrib.contenttypes.models import ContentType
 from django.contrib.sites.models import Site
 from django.template import Template, TemplateSyntaxError
 from menus.base import NavigationNode
 from menus.menu_pool import menu_pool, _build_nodes_inner_for_one_menu
+from menus.models import CacheKey
 from menus.utils import mark_descendants, find_selected, cut_levels
 
 
+
 class BaseMenuTest(SettingsOverrideTestCase):
     settings_overrides = {
         'CMS_MODERATOR': False,
@@ -111,17 +112,40 @@ class FixturesMenuTests(MenusFixture, BaseMenuTest):
     def test_show_menu_num_queries(self):
         context = self.get_context()
         # test standard show_menu 
-        with self.assertNumQueries(4):
+        with self.assertNumQueries(5):
             """
-            The 4 queries should be:
+            The queries should be:
                 get all pages
                 get all page permissions
                 get all titles
+                get the menu cache key
                 set the menu cache key
             """
             tpl = Template("{% load menu_tags %}{% show_menu %}")
             tpl.render(context)
-        
+
+    def test_show_menu_cache_key_leak(self):
+        context = self.get_context()
+        tpl = Template("{% load menu_tags %}{% show_menu %}")
+        self.assertEqual(CacheKey.objects.count(), 0)
+        tpl.render(context)
+        self.assertEqual(CacheKey.objects.count(), 1)
+        tpl.render(context)
+        self.assertEqual(CacheKey.objects.count(), 1)
+
+    def test_menu_keys_duplicate_truncates(self):
+        """
+        When two objects with the same characteristics are present in the
+        database, get_or_create truncates the database table to "invalidate"
+        the cache, before retrying. This can happen after migrations, and since
+        it's only cache, we don't want any propagation of errors.
+        """
+        CacheKey.objects.create(language="fr", site=1, key="a")
+        CacheKey.objects.create(language="fr", site=1, key="a")
+        CacheKey.objects.get_or_create(language="fr", site=1, key="a")
+
+        self.assertEqual(CacheKey.objects.count(), 1)
+
     def test_only_active_tree(self):
         context = self.get_context()
         # test standard show_menu
@@ -319,93 +343,6 @@ class FixturesMenuTests(MenusFixture, BaseMenuTest):
         nodes = context['children']
         self.assertEqual(len(nodes), 2)
         
-    def test_softroot(self):
-        """
-        What is a soft root?
-        
-            If a page is a soft root, it becomes the root page in the menu if
-            we are currently on or under that page.
-            
-            If we are above that page, the children of this page are not shown.
-
-        Tree from fixture:
-            
-            + P1
-            | + P2 <- SOFTROOT
-            |   + P3
-            + P4
-            | + P5
-            + P6 (not in menu)
-              + P7
-              + P8
-        """
-        page2 = Page.objects.get(pk=self.get_page(2).pk)
-        page2.soft_root = True
-        page2.save()
-        # current page: P2
-        context = self.get_context(path=page2.get_absolute_url())
-        tpl = Template("{% load menu_tags %}{% show_menu 0 100 100 100 %}")
-        tpl.render(context) 
-        nodes = context['children']
-        """
-        Assert that the top level contains only ONE page (P2), not 2: P1 and P4!
-        """
-        self.assertEqual(len(nodes), 1)
-        self.assertEqual(nodes[0].get_absolute_url(), page2.get_absolute_url())
-        # current page: P3
-        page3 = Page.objects.get(pk=self.get_page(3).pk)
-        context = self.get_context(path=page3.get_absolute_url())
-        tpl = Template("{% load menu_tags %}{% show_menu 0 100 100 100 %}")
-        tpl.render(context) 
-        nodes = context['children']
-        """
-        Assert that the top level contains only ONE page (P2), not 2: P1 and P4!
-        """
-        self.assertEqual(len(nodes), 1)
-        self.assertEqual(nodes[0].get_absolute_url(), page2.get_absolute_url())
-        
-        # current page: P1
-        page1 = Page.objects.get(pk=self.get_page(1).pk)
-        context = self.get_context(path=page1.get_absolute_url())
-        tpl = Template("{% load menu_tags %}{% show_menu 0 100 100 100 %}")
-        tpl.render(context) 
-        nodes = context['children']
-        """
-        Assert that we have two pages in root level: P1 and P4, because the
-        softroot is below this level.
-        """
-        self.assertEqual(len(nodes), 2)
-        # check that the first page is P1
-        self.assertEqual(nodes[0].get_absolute_url(), page1.get_absolute_url())
-        # check that we don't show the children of P2, which is a soft root!
-        self.assertEqual(len(nodes[0].children[0].children), 0)
-        
-        # current page: NO PAGE
-        context = self.get_context(path="/no/real/path/")
-        tpl = Template("{% load menu_tags %}{% show_menu 0 100 100 100 %}")
-        tpl.render(context) 
-        """
-        Check behavior is the same as on P1
-        """
-        nodes = context['children']
-        self.assertEqual(len(nodes), 2)
-        self.assertEqual(nodes[0].get_absolute_url(), page1.get_absolute_url())
-        self.assertEqual(len(nodes[0].children[0].children), 0)
-        
-        # current page: P5
-        page5 = Page.objects.get(pk=self.get_page(5).pk)
-        context = self.get_context(path=page5.get_absolute_url())
-        tpl = Template("{% load menu_tags %}{% show_menu 0 100 100 100 %}")
-        tpl.render(context)
-        """
-        Again, check the behavior is the same as on P1, because we're not under
-        a soft root! 
-        """
-        nodes = context['children']
-        self.assertEqual(len(nodes), 2)
-        self.assertEqual(nodes[0].get_absolute_url(), page1.get_absolute_url())
-        self.assertEqual(len(nodes[0].children[0].children), 0)
-        
     def test_show_submenu_from_non_menu_page(self):
         """
         Here's the structure bit we're interested in:
@@ -752,12 +689,13 @@ class ShowSubMenuCheck(SubMenusFixture, BaseMenuTest):
         page = Page.objects.get(title_set__title='P6')
         context = self.get_context(page.get_absolute_url())
         # test standard show_menu
-        with self.assertNumQueries(4):
+        with self.assertNumQueries(5):
             """
-            The 4 queries should be:
+            The queries should be:
                 get all pages
                 get all page permissions
                 get all titles
+                get the menu cache key
                 set the menu cache key
             """
             tpl = Template("{% load menu_tags %}{% show_sub_menu %}")
@@ -777,7 +715,7 @@ class ShowMenuBelowIdTests(BaseMenuTest):
         """
         a = create_page('A', 'nav_playground.html', 'en', published=True,
                         in_navigation=True, reverse_id='a')
-        b =create_page('B', 'nav_playground.html', 'en', parent=a,
+        b = create_page('B', 'nav_playground.html', 'en', parent=a,
                        published=True, in_navigation=True)
         c = create_page('C', 'nav_playground.html', 'en', parent=b,
                         published=True, in_navigation=True)
@@ -810,18 +748,19 @@ class ShowMenuBelowIdTests(BaseMenuTest):
                         in_navigation=True, reverse_id='a')
         b =create_page('B', 'nav_playground.html', 'en', parent=a,
                        published=True, in_navigation=True)
-        c = create_page('C', 'nav_playground.html', 'en', parent=b,
+        create_page('C', 'nav_playground.html', 'en', parent=b,
                         published=True, in_navigation=True)
         create_page('D', 'nav_playground.html', 'en', parent=self.reload(b),
                     published=True, in_navigation=False)
         with LanguageOverride('en'):
             context = self.get_context(a.get_absolute_url())
-            with self.assertNumQueries(4):
+            with self.assertNumQueries(5):
                 """
-                The 4 queries should be:
+                The queries should be:
                     get all pages
                     get all page permissions
                     get all titles
+                    get the menu cache key
                     set the menu cache key
                 """
                 # Actually seems to run:
@@ -849,6 +788,8 @@ class ViewPermissionMenuTests(SettingsOverrideTestCase):
         request.user.is_staff = True
         page = Page()
         page.pk = 1
+        page.level = 0
+        page.tree_id = 1
         pages = [page]
         result = get_visible_pages(request, pages)
         self.assertEqual(result, [1])
@@ -858,8 +799,14 @@ class ViewPermissionMenuTests(SettingsOverrideTestCase):
         request.user.is_staff = True
         page = Page()
         page.pk = 1
+        page.level = 0
+        page.tree_id = 1
         pages = [page]
-        with self.assertNumQueries(0):
+        with self.assertNumQueries(1):
+            """
+                The queries are:
+                PagePermission count query
+            """    
             get_visible_pages(request, pages)
     
     def test_public_for_all(self):
@@ -921,7 +868,10 @@ class ViewPermissionMenuTests(SettingsOverrideTestCase):
     
     def test_authed_basic_perm(self):
         with SettingsOverride(CMS_PUBLIC_FOR='staff'):
-            user = User.objects.create_user('user', 'user@domain.com', 'user')
+            user = User()
+            user.username="test"
+            user.is_staff = True
+            user.save()
             user.user_permissions.add(Permission.objects.get(codename='view_page'))
             request = self.get_request(user)
             page = Page()
@@ -936,7 +886,10 @@ class ViewPermissionMenuTests(SettingsOverrideTestCase):
         site = Site()
         site.pk = 1
         with SettingsOverride(CMS_PUBLIC_FOR='staff'):
-            user = User.objects.create_user('user', 'user@domain.com', 'user')
+            user = User()
+            user.username="test"
+            user.is_staff = True
+            user.save()
             user.user_permissions.add(Permission.objects.get(codename='view_page'))
             request = self.get_request(user)
             page = Page()
@@ -944,13 +897,11 @@ class ViewPermissionMenuTests(SettingsOverrideTestCase):
             page.level = 0
             page.tree_id = 1
             pages = [page]
-            with self.assertNumQueries(4):
+            with self.assertNumQueries(2):
                 """
                 The queries are:
-                PagePermission query for affected pages
-                GlobalpagePermission query for user
-                Generic django permission lookup
-                content type lookup by permission lookup
+                PagePermission count query 
+                GlobalpagePermission count query
                 """
                 get_visible_pages(request, pages, site)
     
@@ -977,13 +928,11 @@ class ViewPermissionMenuTests(SettingsOverrideTestCase):
             page.level = 0
             page.tree_id = 1
             pages = [page]
-            with self.assertNumQueries(4):
+            with self.assertNumQueries(2):
                 """
                 The queries are:
-                PagePermission query for affected pages
-                GlobalpagePermission query for user
-                Generic django permission lookup
-                content type lookup by permission lookup
+                View Permission Calculation Query
+                globalpagepermissino calculation
                 """
                 get_visible_pages(request, pages, site)
     
@@ -1098,3 +1047,262 @@ class ViewPermissionMenuTests(SettingsOverrideTestCase):
             GlobalpagePermission query for user
             """
             get_visible_pages(request, pages, site)
+
+class SoftrootTests(SettingsOverrideTestCase):
+    """
+    Ask evildmp/superdmp if you don't understand softroots!
+    
+    Softroot description from the docs:
+    
+        A soft root is a page that acts as the root for a menu navigation tree.
+    
+        Typically, this will be a page that is the root of a significant new
+        section on your site.
+    
+        When the soft root feature is enabled, the navigation menu for any page
+        will start at the nearest soft root, rather than at the real root of
+        the site’s page hierarchy.
+    
+        This feature is useful when your site has deep page hierarchies (and
+        therefore multiple levels in its navigation trees). In such a case, you
+        usually don’t want to present site visitors with deep menus of nested
+        items.
+    
+        For example, you’re on the page “Introduction to Bleeding”, so the menu
+        might look like this:
+    
+            School of Medicine
+                Medical Education
+                Departments
+                    Department of Lorem Ipsum
+                    Department of Donec Imperdiet
+                    Department of Cras Eros
+                    Department of Mediaeval Surgery
+                        Theory
+                        Cures
+                        Bleeding
+                            Introduction to Bleeding <this is the current page>
+                            Bleeding - the scientific evidence
+                            Cleaning up the mess
+                            Cupping
+                            Leaches
+                            Maggots
+                        Techniques
+                        Instruments
+                    Department of Curabitur a Purus
+                    Department of Sed Accumsan
+                    Department of Etiam
+                Research
+                Administration
+                Contact us
+                Impressum
+    
+        which is frankly overwhelming.
+    
+        By making “Department of Mediaeval Surgery” a soft root, the menu
+        becomes much more manageable:
+    
+            Department of Mediaeval Surgery
+                Theory
+                Cures
+                    Bleeding
+                        Introduction to Bleeding <current page>
+                        Bleeding - the scientific evidence
+                        Cleaning up the mess
+                    Cupping
+                    Leaches
+                    Maggots
+                Techniques
+                Instruments
+    """
+    settings_overrides = {
+        'CMS_MODERATOR': False,
+        'CMS_SOFTROOT': True,
+        'CMS_PERMISSION': False
+    }
+    
+    def test_basic_home(self):
+        """
+        Given the tree:
+        
+        |- Home
+        | |- Projects (SOFTROOT)
+        | | |- django CMS
+        | | |- django Shop
+        | |- People
+        
+        Expected menu when on "Home" (0 100 100 100):
+        
+        |- Home
+        | |- Projects (SOFTROOT)
+        | | |- django CMS
+        | | |- django Shop
+        | |- People
+        """
+        stdkwargs = {
+            'template': 'nav_playground.html',
+            'language': 'en',
+            'published': True,
+            'in_navigation': True,
+        }
+        home = create_page("Home", **stdkwargs)
+        projects = create_page("Projects", parent=Page.objects.get(pk=home.pk), soft_root=True, **stdkwargs)
+        djangocms = create_page("django CMS", parent=Page.objects.get(pk=projects.pk), **stdkwargs)
+        djangoshop = create_page("django Shop", parent=Page.objects.get(pk=projects.pk), **stdkwargs)
+        people = create_page("People", parent=Page.objects.get(pk=home.pk), **stdkwargs)
+        # On Home
+        context = self.get_context(home.get_absolute_url())
+        tpl = Template("{% load menu_tags %}{% show_menu 0 100 100 100 %}")
+        tpl.render(context)
+        nodes = context['children']
+        # check everything
+        self.assertEqual(len(nodes), 1)
+        homenode = nodes[0]
+        self.assertEqual(homenode.id, home.pk)
+        self.assertEqual(len(homenode.children), 2)
+        projectsnode, peoplenode = homenode.children
+        self.assertEqual(projectsnode.id, projects.pk)
+        self.assertEqual(peoplenode.id, people.pk)
+        self.assertEqual(len(projectsnode.children), 2)
+        cmsnode, shopnode = projectsnode.children
+        self.assertEqual(cmsnode.id, djangocms.pk)
+        self.assertEqual(shopnode.id, djangoshop.pk)
+        self.assertEqual(len(cmsnode.children), 0)
+        self.assertEqual(len(shopnode.children), 0)
+        self.assertEqual(len(peoplenode.children), 0)
+        
+    def test_basic_projects(self):
+        """
+        Given the tree:
+        
+        |- Home
+        | |- Projects (SOFTROOT)
+        | | |- django CMS
+        | | |- django Shop
+        | |- People
+        
+        Expected menu when on "Projects" (0 100 100 100):
+        
+        |- Projects (SOFTROOT)
+        | |- django CMS
+        | |- django Shop
+        """
+        stdkwargs = {
+            'template': 'nav_playground.html',
+            'language': 'en',
+            'published': True,
+            'in_navigation': True,
+        }
+        home = create_page("Home", **stdkwargs)
+        projects = create_page("Projects", parent=Page.objects.get(pk=home.pk), soft_root=True, **stdkwargs)
+        djangocms = create_page("django CMS", parent=Page.objects.get(pk=projects.pk), **stdkwargs)
+        djangoshop = create_page("django Shop", parent=Page.objects.get(pk=projects.pk), **stdkwargs)
+        people = create_page("People", parent=Page.objects.get(pk=home.pk), **stdkwargs)
+        # On Projects
+        context = self.get_context(projects.get_absolute_url())
+        tpl = Template("{% load menu_tags %}{% show_menu 0 100 100 100 %}")
+        tpl.render(context)
+        nodes = context['children']
+        # check everything
+        self.assertEqual(len(nodes), 1)
+        projectsnode = nodes[0]
+        self.assertEqual(projectsnode.id, projects.pk)
+        self.assertEqual(len(projectsnode.children), 2)
+        cmsnode, shopnode = projectsnode.children
+        self.assertEqual(cmsnode.id, djangocms.pk)
+        self.assertEqual(shopnode.id, djangoshop.pk)
+        self.assertEqual(len(cmsnode.children), 0)
+        self.assertEqual(len(shopnode.children), 0)
+        
+    def test_basic_djangocms(self):
+        """
+        Given the tree:
+        
+        |- Home
+        | |- Projects (SOFTROOT)
+        | | |- django CMS
+        | | |- django Shop
+        | |- People
+        
+        Expected menu when on "django CMS" (0 100 100 100):
+        
+        |- Projects (SOFTROOT)
+        | |- django CMS
+        | |- django Shop
+        """
+        stdkwargs = {
+            'template': 'nav_playground.html',
+            'language': 'en',
+            'published': True,
+            'in_navigation': True,
+        }
+        home = create_page("Home", **stdkwargs)
+        projects = create_page("Projects", parent=Page.objects.get(pk=home.pk), soft_root=True, **stdkwargs)
+        djangocms = create_page("django CMS", parent=Page.objects.get(pk=projects.pk), **stdkwargs)
+        djangoshop = create_page("django Shop", parent=Page.objects.get(pk=projects.pk), **stdkwargs)
+        people = create_page("People", parent=Page.objects.get(pk=home.pk), **stdkwargs)
+        # On django CMS
+        context = self.get_context(djangocms.get_absolute_url())
+        tpl = Template("{% load menu_tags %}{% show_menu 0 100 100 100 %}")
+        tpl.render(context)
+        nodes = context['children']
+        # check everything
+        self.assertEqual(len(nodes), 1)
+        projectsnode = nodes[0]
+        self.assertEqual(projectsnode.id, projects.pk)
+        self.assertEqual(len(projectsnode.children), 2)
+        cmsnode, shopnode = projectsnode.children
+        self.assertEqual(cmsnode.id, djangocms.pk)
+        self.assertEqual(shopnode.id, djangoshop.pk)
+        self.assertEqual(len(cmsnode.children), 0)
+        self.assertEqual(len(shopnode.children), 0)
+        
+    def test_basic_people(self):
+        """
+        Given the tree:
+        
+        |- Home
+        | |- Projects (SOFTROOT)
+        | | |- django CMS
+        | | |- django Shop
+        | |- People
+        
+        Expected menu when on "People" (0 100 100 100):
+        
+        |- Home
+        | |- Projects (SOFTROOT)
+        | | |- django CMS
+        | | |- django Shop
+        | |- People
+        """
+        stdkwargs = {
+            'template': 'nav_playground.html',
+            'language': 'en',
+            'published': True,
+            'in_navigation': True,
+        }
+        home = create_page("Home", **stdkwargs)
+        projects = create_page("Projects", parent=Page.objects.get(pk=home.pk), soft_root=True, **stdkwargs)
+        djangocms = create_page("django CMS", parent=Page.objects.get(pk=projects.pk), **stdkwargs)
+        djangoshop = create_page("django Shop", parent=Page.objects.get(pk=projects.pk), **stdkwargs)
+        people = create_page("People", parent=Page.objects.get(pk=home.pk), **stdkwargs)
+        # On People
+        context = self.get_context(home.get_absolute_url())
+        tpl = Template("{% load menu_tags %}{% show_menu 0 100 100 100 %}")
+        tpl.render(context)
+        nodes = context['children']
+        # check everything
+        self.assertEqual(len(nodes), 1)
+        homenode = nodes[0]
+        self.assertEqual(homenode.id, home.pk)
+        self.assertEqual(len(homenode.children), 2)
+        projectsnode, peoplenode = homenode.children
+        self.assertEqual(projectsnode.id, projects.pk)
+        self.assertEqual(peoplenode.id, people.pk)
+        self.assertEqual(len(projectsnode.children), 2)
+        cmsnode, shopnode = projectsnode.children
+        self.assertEqual(cmsnode.id, djangocms.pk)
+        self.assertEqual(shopnode.id, djangoshop.pk)
+        self.assertEqual(len(cmsnode.children), 0)
+        self.assertEqual(len(shopnode.children), 0)
+        self.assertEqual(len(peoplenode.children), 0)
