@@ -10,23 +10,23 @@ from cms.plugins.link.cms_plugins import LinkPlugin
 from cms.plugins.text.cms_plugins import TextPlugin
 from cms.plugins.text.models import Text
 from cms.test_utils.fixtures.fakemlng import FakemlngFixtures
+from cms.test_utils.project.fakemlng.models import Translations
+from cms.test_utils.project.placeholderapp.models import (Example1, Example2, 
+    Example3, Example4, Example5)
 from cms.test_utils.testcases import CMSTestCase, TestCase
 from cms.test_utils.util.context_managers import (SettingsOverride, 
     UserLoginContext)
 from cms.test_utils.util.mock import AttributeObject
-from cms.utils.placeholder import (PlaceholderNoAction, MLNGPlaceholderActions, 
-    get_placeholder_conf)
+from cms.utils.placeholder import PlaceholderNoAction, MLNGPlaceholderActions
 from cms.utils.plugins import get_placeholders
 from django.conf import settings
 from django.contrib import admin
 from django.contrib.auth.models import User, Permission
+from django.contrib.messages.storage import default_storage
 from django.core.urlresolvers import reverse
 from django.http import HttpResponseForbidden, HttpResponse
 from django.template import TemplateSyntaxError, Template
 from django.template.context import Context, RequestContext
-from project.fakemlng.models import Translations
-from project.placeholderapp.models import (Example1, Example2, Example3, 
-    Example4, Example5)
 
 
 class PlaceholderTestCase(CMSTestCase):
@@ -72,6 +72,10 @@ class PlaceholderTestCase(CMSTestCase):
     def test_placeholder_scanning_extend_outside_block(self):
         placeholders = get_placeholders('placeholder_tests/outside.html')
         self.assertEqual(sorted(placeholders), sorted([u'new_one', u'two', u'base_outside']))
+
+    def test_placeholder_scanning_extend_outside_block_nested(self):
+        placeholders = get_placeholders('placeholder_tests/outside_nested.html')
+        self.assertEqual(sorted(placeholders), sorted([u'new_one', u'two', u'base_outside']))
     
     def test_fieldsets_requests(self):
         response = self.client.get(reverse('admin:placeholderapp_example1_add'))
@@ -86,7 +90,7 @@ class PlaceholderTestCase(CMSTestCase):
         self.assertEqual(response.status_code, 200)
         
     def test_fieldsets(self):
-        from project.placeholderapp import admin as __ # load admin
+        from cms.test_utils.project.placeholderapp import admin as __ # load admin
         request = self.get_request('/')
         admins = [
             (Example1, 2),
@@ -435,6 +439,7 @@ class PlaceholderPluginPermissionTests(PlaceholderAdminTest):
         }
         request = self.get_post_request(data)
         request.user = self.reload(user)
+        request._messages = default_storage(request)
         return request
 
     def test_plugin_add_requires_permissions(self):
