@@ -15,6 +15,9 @@ from cms.plugins.text.models import Text
 from cms.plugins.text.utils import (plugin_tags_to_id_list, 
     plugin_tags_to_admin_html)
 from cms.plugins.twitter.models import TwitterRecentEntries
+from cms.test_utils.project.pluginapp.models import Article, Section
+from cms.test_utils.project.pluginapp.plugins.manytomany_rel.models import (
+    ArticlePluginModel)
 from cms.test_utils.testcases import (CMSTestCase, URL_CMS_PAGE, 
     URL_CMS_PAGE_ADD, URL_CMS_PLUGIN_ADD, URL_CMS_PLUGIN_EDIT, URL_CMS_PAGE_CHANGE, 
     URL_CMS_PLUGIN_REMOVE)
@@ -27,8 +30,6 @@ from django.core.files.uploadedfile import SimpleUploadedFile
 from django.core.management import call_command
 from django.forms.widgets import Media
 from django.test.testcases import TestCase
-from project.pluginapp.models import Article, Section
-from project.pluginapp.plugins.manytomany_rel.models import ArticlePluginModel
 import os
 
 
@@ -102,6 +103,44 @@ class PluginsTestCase(PluginsTestBaseCase):
         self.assertEquals(response.status_code, 200)
         txt = Text.objects.all()[0]
         self.assertEquals("Hello World", txt.body)
+        # edit body, but click cancel button
+        data = {
+            "body":"Hello World!!",
+            "_cancel":True,
+        }
+        response = self.client.post(edit_url, data)
+        self.assertEquals(response.status_code, 200)
+        txt = Text.objects.all()[0]
+        self.assertEquals("Hello World", txt.body)
+
+    def test_add_cancel_plugin(self):
+        """
+        Test that you can cancel a new plugin before editing and 
+        that the plugin is removed.
+        """
+        # add a new text plugin
+        page_data = self.get_new_page_data()
+        response = self.client.post(URL_CMS_PAGE_ADD, page_data)
+        page = Page.objects.all()[0]
+        plugin_data = {
+            'plugin_type':"TextPlugin",
+            'language':settings.LANGUAGES[0][0],
+            'placeholder':page.placeholders.get(slot="body").pk,
+        }
+        response = self.client.post(URL_CMS_PLUGIN_ADD, plugin_data)
+        self.assertEquals(response.status_code, 200)
+        self.assertEquals(int(response.content), CMSPlugin.objects.all()[0].pk)
+        # now click cancel instead of editing
+        edit_url = URL_CMS_PLUGIN_EDIT + response.content + "/"
+        response = self.client.get(edit_url)
+        self.assertEquals(response.status_code, 200)
+        data = {
+            "body":"Hello World",
+            "_cancel":True,
+        }
+        response = self.client.post(edit_url, data)
+        self.assertEquals(response.status_code, 200)
+        self.assertEquals(0, Text.objects.count())
 
     def test_copy_plugins(self):
         """
@@ -410,7 +449,9 @@ class PluginsTestCase(PluginsTestBaseCase):
         self.assertEquals(CMSPlugin.objects.count(), 6)
 
         new_plugin = Text.objects.get(pk=6)
-        self.assertEquals(plugin_tags_to_id_list(new_plugin.body), [u'4', u'5'])
+        idlist = sorted(plugin_tags_to_id_list(new_plugin.body))
+        expected = sorted([u'4', u'5'])
+        self.assertEquals(idlist, expected)
 
 
 class FileSystemPluginTests(PluginsTestBaseCase):
@@ -607,6 +648,70 @@ class PluginManyToManyTestCase(PluginsTestBaseCase):
         expected = [self.section_count for i in range(len(db_counts))]
         self.assertEqual(expected, db_counts)
         
+class PluginsMetaOptionsTests(TestCase):
+    ''' TestCase set for ensuring that bugs like #992 are caught '''
+
+    # these plugins are inlined because, due to the nature of the #992
+    # ticket, we cannot actually import a single file with all the
+    # plugin variants in, because that calls __new__, at which point the
+    # error with splitted occurs.
+
+    def test_meta_options_as_defaults(self):
+        ''' handling when a CMSPlugin meta options are computed defaults '''
+        # this plugin relies on the base CMSPlugin and Model classes to
+        # decide what the app_label and db_table should be
+        class TestPlugin(CMSPlugin):
+            pass
+
+        plugin = TestPlugin()
+        self.assertEqual(plugin._meta.db_table, 'cmsplugin_testplugin')
+        self.assertEqual(plugin._meta.app_label, 'tests') # because it's inlined
+
+    def test_meta_options_as_declared_defaults(self):
+        ''' handling when a CMSPlugin meta options are declared as per defaults '''
+        # here, we declare the db_table and app_label explicitly, but to the same
+        # values as would be computed, thus making sure it's not a problem to
+        # supply options.
+        class TestPlugin2(CMSPlugin):
+            class Meta:
+                db_table = 'cmsplugin_testplugin2'
+                app_label = 'tests'
+
+        plugin = TestPlugin2()
+        self.assertEqual(plugin._meta.db_table, 'cmsplugin_testplugin2')
+        self.assertEqual(plugin._meta.app_label, 'tests') # because it's inlined
+
+    def test_meta_options_custom_app_label(self):
+        ''' make sure customised meta options on CMSPlugins don't break things '''
+
+        class TestPlugin3(CMSPlugin):
+            class Meta:
+                app_label = 'one_thing'
+
+        plugin = TestPlugin3()
+        self.assertEqual(plugin._meta.db_table, 'cmsplugin_testplugin3') # because it's inlined
+        self.assertEqual(plugin._meta.app_label, 'one_thing')
+
+    def test_meta_options_custom_db_table(self):
+        ''' make sure custom database table names are OK. '''
+        class TestPlugin4(CMSPlugin):
+            class Meta:
+                db_table = 'or_another'
+
+        plugin = TestPlugin4()
+        self.assertEqual(plugin._meta.db_table, 'or_another')
+        self.assertEqual(plugin._meta.app_label, 'tests') # because it's inlined
+
+    def test_meta_options_custom_both(self):
+        ''' We should be able to customise app_label and db_table together '''
+        class TestPlugin5(CMSPlugin):
+            class Meta:
+                app_label = 'one_thing'
+                db_table = 'or_another'
+
+        plugin = TestPlugin5()
+        self.assertEqual(plugin._meta.db_table, 'or_another')
+        self.assertEqual(plugin._meta.app_label, 'one_thing')
 
 class SekizaiTests(TestCase):
     def test_post_patch_check(self):
